Stan Math Library: stan/math/rev/scal/meta/partials_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

partials_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_META_PARTIALS_TYPE_HPP
2 #define STAN_MATH_REV_SCAL_META_PARTIALS_TYPE_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/meta/partials_type.hpp>
6
7 namespace stan {
8
9 template <>
10 struct partials_type<stan::math::var> {
11 typedef double type;
12 };
13
14 }
15 #endif
16
stan::partials_type< stan::math::var >::type
double type
Definition: partials_type.hpp:11
core.hpp
stan
Definition: log_sum_exp.hpp:8
partials_type.hpp
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::partials_type
Definition: partials_type.hpp:7

[ Stan Home Page ] © 2011–2016, Stan Development Team.